==> modules_fruserdynav2_20210316082222.zip: fruserdynav2/up.sql <==
--
-- Host: localhost:3306
-- Generation Time: Mar 10, 2021 at 09:11 PM
-- Server version: 5.6.51
-- PHP Version: 7.3.6

SET SQL_MODE = "NO_AUTO_VALUE_ON_ZERO";
SET AUTOCOMMIT = 0;
START TRANSACTION;
SET time_zone = "+00:00";

--
-- Database: `blunetde_intranetjppm`
--

-- --------------------------------------------------------

--
-- Table structure for table `frontend_user`
--

CREATE TABLE `frontend_user` (
  `id` int(11) NOT NULL,
  `username` varchar(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL,
  `fullname` varchar(255) NOT NULL,
  `auth_key` varchar(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci DEFAULT NULL,
  `password_hash` varchar(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL,
  `password_reset_token` varchar(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci DEFAULT NULL,
  `email` varchar(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL,
  `last_login` int(11) DEFAULT NULL,
  `last_login_attempts` int(11) DEFAULT NULL,
  `login_attempts` int(11) DEFAULT NULL,
  `status` enum('A','I') DEFAULT NULL,
  `role` varchar(50) DEFAULT NULL,
  `created_by` varchar(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci DEFAULT NULL,
  `created_at` datetime DEFAULT CURRENT_TIMESTAMP,
  `updated_by` varchar(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci DEFAULT NULL,
  `updated_at` datetime DEFAULT CURRENT_TIMESTAMP,
  `frontend_usercol` varchar(45) DEFAULT NULL,
  `id_pertubuhan` int(11) DEFAULT NULL,
  `registrant_id` varchar(45) DEFAULT NULL,
  `parent_id` int(11) DEFAULT '0',
  `branch_name` varchar(255) DEFAULT NULL,
  `branch_no` varchar(45) DEFAULT NULL,
  `designation` varchar(50) DEFAULT NULL,
  `department` varchar(50) DEFAULT NULL,
  `designation_en` varchar(50) DEFAULT NULL,
  `department_en` varchar(50) DEFAULT NULL,
  `usericon` varchar(255) DEFAULT NULL,
  `directory_id` int(11) DEFAULT NULL
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Indexes for dumped tables
--

--
-- Indexes for table `frontend_user`
--
ALTER TABLE `frontend_user`
  ADD PRIMARY KEY (`id`);

--
-- AUTO_INCREMENT for dumped tables
--

--
-- AUTO_INCREMENT for table `frontend_user`
--
ALTER TABLE `frontend_user`
  MODIFY `id` int(11) NOT NULL AUTO_INCREMENT;
COMMIT;

==> modules_fruserdynav2_20210707113841.zip: fruserdynav2/up.sql <==
--
-- Host: localhost:3306
-- Generation Time: Mar 10, 2021 at 09:11 PM
-- Server version: 5.6.51
-- PHP Version: 7.3.6

SET SQL_MODE = "NO_AUTO_VALUE_ON_ZERO";
SET AUTOCOMMIT = 0;
START TRANSACTION;
SET time_zone = "+00:00";

-- --------------------------------------------------------

--
-- Table structure for table `frontend_user`
--

CREATE TABLE `frontend_user` (
  `id` int(11) NOT NULL,
  `username` varchar(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL,
  `fullname` varchar(255) NOT NULL,
  `email` varchar(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL,
  `designation` varchar(50) DEFAULT NULL,
  `state` varchar(255) DEFAULT NULL,
  `branch` varchar(255) DEFAULT NULL,
  `department` varchar(50) DEFAULT NULL,
  `unit` varchar(255) DEFAULT NULL,
  `mobile_no` varchar(255) DEFAULT NULL,
  `office_no` varchar(255) DEFAULT NULL,
  `gender` varchar(255) DEFAULT NULL,
  `service_status` varchar(255) DEFAULT NULL,
  `service_status_latest` varchar(255) DEFAULT NULL,
  `service_group` varchar(255) DEFAULT NULL,
  `service_classification` varchar(255) DEFAULT NULL,
  `gred` varchar(255) DEFAULT NULL,
  `gred_post` varchar(255) DEFAULT NULL,
  `remarks` text DEFAULT NULL,
  `status` int(11) DEFAULT NULL,
  `role` varchar(50) DEFAULT NULL,
  `img_url` varchar(255) DEFAULT NULL,
  `auth_key` varchar(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci DEFAULT NULL,
  `password_hash` varchar(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci NOT NULL,
  `password_reset_token` varchar(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci DEFAULT NULL,
  `last_login` int(11) DEFAULT NULL,
  `last_login_attempts` int(11) DEFAULT NULL,
  `login_attempts` int(11) DEFAULT NULL,
  `created_at` datetime DEFAULT NULL,
  `created_by` varchar(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci DEFAULT NULL,
  `created_user_type` varchar(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `updated_by` varchar(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci DEFAULT NULL,
  `updated_user_type` varchar(255) CHARACTER SET utf8 COLLATE utf8_unicode_ci DEFAULT NULL
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Indexes for dumped tables
--

--
-- Indexes for table `frontend_user`
--
ALTER TABLE `frontend_user`
  ADD PRIMARY KEY (`id`);

--
-- AUTO_INCREMENT for dumped tables
--

--
-- AUTO_INCREMENT for table `frontend_user`
--
ALTER TABLE `frontend_user`
  MODIFY `id` int(11) NOT NULL AUTO_INCREMENT;
COMMIT;
